{pkgs, ...}: {
  nix.settings = {
    trusted-substituters = [
      "https://t2linux.cachix.org"
    ];
    trusted-public-keys = [
      "t2linux.cachix.org-1:P733c5Gt1qTcxsm+Bae0renWnT8OLs0u9+yfaK2Bejw="
    ];
  };
  imports = [
    ./hardware-configuration.nix
    ../../common.nix
    ../../modules
  ];

  boot.binfmt.emulatedSystems = ["aarch64-linux"];

  jade = {
    flatpak.enable = true;
    desktop = {
      compositing.enable = true;
      syncthing.enable = true;
      kdeconnect.enable = true;
      cloud.enable = true;
      social.enable = true;
      mail.enable = true;
      gaming.enable = true;
      evremap.enable = true;
    };
    terminal.enable = true;
  };

  fileSystems = {
    "/".options = ["compress=zstd:3"];
    "/home".options = ["compress=zstd:3"];
    "/nix".options = ["compress=zstd:3" "noatime"];
  };

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  services.libinput.touchpad = {
    disableWhileTyping = true;
  };

  networking.hostName = "potatobook-g";

  hardware.enableRedistributableFirmware = true;

  environment.pathsToLink = [
    "/share/nix-direnv"
  ];

  services.blueman.enable = true;

  programs.adb.enable = true;

  services.gnome.gnome-keyring.enable = true;
  programs.seahorse.enable = true;
  security.pam.services.jade.enableGnomeKeyring = true;

  systemd.services."NetworkManager-wait-online".enable = false;

  systemd.services = {
    create-swapfile = {
      serviceConfig.Type = "oneshot";
      wantedBy = ["swap-swapfile.swap"];
      script = ''
        swapfile="/swap/swapfile"
        if [[ -f "$swapfile" ]]; then
          echo "Swap file $swapfile already exists, taking no action"
        else
          echo "Setting up swap file $swapfile"
          ${pkgs.coreutils}/bin/truncate -s 0 "$swapfile"
          ${pkgs.e2fsprogs}/bin/chattr +C "$swapfile"
        fi
      '';
    };
  };

  services.logind.extraConfig = ''
    RuntimeDirectorySize=12G
  '';

  # i rly should put that important big comment back here
  system.stateVersion = "22.11"; # Did you read the comment?
}
